# AOMaker

*AOMaker* means "api object maker",yes,It can help you play your API like building blocks !

## Design Philosophy

- Based on the design idea of api object
- Anything is modularized and abstracted
- Return to the coding,balance generality and flexibility

## Key Features

- integrate *requests,pytest,allure*
- layered structure:base api--api definition--api object--case--testcase--testdata
- Import custom fixture automatically
- generate api object automatically by *swagger*
- generate testcase automatically by *api object*
- Switch test environment with one click
- CLI command supported

